==> simple_analytics-8.x-2.1-rc2.tar.gz: simple_analytics/src/Controller/SimpleAnalyticsTracker.php <==
<?php

namespace Drupal\simple_analytics\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\Core\Database\Database;
use Drupal\simple_analytics\SimpleAnalyticsService;

/**
 * Simple Analytics Functions.
 */
class SimpleAnalyticsTracker extends ControllerBase {

  /**
   * Input / Process a log.
   */
  public function process() {

    $output = [];
    $output[] = ["rasult" => "OK"];

    // Clean REQUEST.
    foreach ($_POST as $key => $value) {
      if (strstr($key, 'amp;')) {

        $_POST[str_replace('amp;', '', $key)] = $value;
      }
    }

    $data['URL'] = (!empty($_POST['URL'])) ? $_POST['URL'] : "";
    $data['CAMP'] = (!empty($_POST['CAMP'])) ? $_POST['CAMP'] : "";
    $data['REFERER'] = (!empty($_POST['REFERER'])) ? $_POST['REFERER'] : "";
    $data['MOBILE'] = (!empty($_POST['MOBILE'])) ? $_POST['MOBILE'] : "";
    $data['SCREEN'] = (!empty($_POST['SCREEN'])) ? $_POST['SCREEN'] : "";
    $data['LANGUAGE'] = (!empty($_POST['LANGUAGE'])) ? $_POST['LANGUAGE'] : "";
    $data['HTTP_USER_AGENT'] = $_SERVER['HTTP_USER_AGENT'] ? $_SERVER['HTTP_USER_AGENT'] : "";
    $data['REMOTE_ADDR'] = simple_analytics_get_client_ip();
    $data['HTTP_REFERER'] = !empty($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : "";
    $data['BOT'] = SimpleAnalyticsService::botDetecte();
    $data['REQUEST_URI'] = $_SERVER['REQUEST_URI'];
    $data['HTTP_HOST'] = $_SERVER['HTTP_HOST'];

    // Make signature.
    $data['SIGNATURE'] = md5($data['MOBILE'] . $data['SCREEN'] . $data['HTTP_USER_AGENT'] . $data['REMOTE_ADDR']);

    // Add to stat.
    $this->setStat($data);

    return new JsonResponse($output);
  }

  /**
   * Archive yesterday datas and delete old datas.
   *
   * @return bool
   *   TRUE if Done, FALSE otherwise.
   */
  public static function archive() {

    // Date end.
    $date_end = strtotime(date("Y-m-d"));
    // Date Start.
    $date_stt = $date_end - 86400;

    $date_deletearchive = $date_stt - (86400 * 365);
    //
    // Database connection.
    $con = Database::getConnection();

    // Check is already archives.
    $query = $con->select('simple_analytics_archive', 'a');
    $query->fields('a', ['id', 'date']);
    $query->condition('date', $date_stt, '=');
    $result = $query->execute()->fetchAll();

    if (count($result)) {
      // Already archived.
      return FALSE;
    }
    //
    // Archive results.
    $query = $con->select('simple_analytics_data', 'd');
    $query->fields('d', [
      'id',
      'timestamp',
      'MOBILE',
      'BOT',
      'LANGUAGE',
      'SCREEN',
      'SIGNATURE',
    ]);
    $group = $query->andConditionGroup()
      ->condition('timestamp', $date_stt, '>')
      ->condition('timestamp', $date_end, '<');
    $query->condition($group);
    $result = $query->execute()->fetchAll();

    // $visits = count($result);
    $visits = 0;
    $page_view = 0;
    $hits = 0;
    $mobile = 0;
    $entry_direct = 0;
    $bots = 0;
    $bots_hits = 0;
    $settings_data = [];

    $signatures = [];

    foreach ($result as $row) {
      if (isset($signatures[$row->SIGNATURE])) {
        $signatures[$row->SIGNATURE]++;
        $is_new = FALSE;
      }
      else {
        $signatures[$row->SIGNATURE] = 1;
        $is_new = TRUE;
      }

      $hits++;
      if ($row->BOT) {
        if ($is_new) {
          $bots++;
        }
        $bots_hits++;
      }
      elseif ($row->MOBILE) {
        if ($is_new) {
          $mobile++;
        }
      }
      else {
        if ($is_new) {
          $visits++;
          $settings_data['screens'][$row->SCREEN]++;
          $settings_data['languages'][$row->LANGUAGE]++;
        }
        $entry_direct += ($row->REFERER ? 0 : 1);
        $page_view++;
      }
    }

    $query = $con->insert('simple_analytics_archive');
    $query->fields([
      'date',
      'visits',
      'page_view',
      'hits',
      'mobile',
      'entry_direct',
      'bots',
      'bots_hits',
      'settings_data',
    ]);
    $query->values([
      $date_stt,
      $visits,
      $page_view,
      $hits,
      $mobile,
      $entry_direct,
      $bots,
      $bots_hits,
      json_encode($settings_data),
    ]);
    $query->execute();

    // Delete old results.
    $query = $con->delete('simple_analytics_data');
    $query->condition('timestamp', $date_end, '<');
    $result = $query->execute();

    $query = $con->delete('simple_analytics_archive');
    $query->condition('date', $date_deletearchive, '<');
    $result = $query->execute();

    return TRUE;
  }

  /**
   * Add to ststistic.
   *
   * @param array $data
   *   Preprocessed Visitors data.
   */
  private function setStat(array $data) {

    if (!$data['LANGUAGE']) {
      $data['LANGUAGE'] = "und";
    }

    // Database connection.
    $con = Database::getConnection();

    $date_now = time();

    if (session_status() == PHP_SESSION_NONE) {
      session_start();
    }
    $session = session_id();

    $con->insert('simple_analytics_data')
      ->fields([
        'timestamp' => $date_now,
        'session' => $session,
        'REFERER' => $data['REFERER'],
        'MOBILE' => $data['MOBILE'],
        'SCREEN' => $data['SCREEN'],
        'HTTP_USER_AGENT' => $data['HTTP_USER_AGENT'],
        'REMOTE_ADDR' => $data['REMOTE_ADDR'],
        'HTTP_REFERER' => $data['HTTP_REFERER'],
        'LANGUAGE' => $data['LANGUAGE'],
        'SIGNATURE' => $data['SIGNATURE'],
        'REQUEST_URI' => $data['REQUEST_URI'],
        'HTTP_HOST' => $data['HTTP_HOST'],
        'BOT' => $data['BOT'],
      ])
      ->execute();

  }

}

==> simple_analytics-8.x-2.2.tar.gz: simple_analytics/src/Controller/SimpleAnalyticsTracker.php <==
<?php

namespace Drupal\simple_analytics\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\simple_analytics\SimpleAnalyticsService;
use Drupal\simple_analytics\SimpleAnalyticsActions;

/**
 * Simple Analytics Functions.
 */
class SimpleAnalyticsTracker extends ControllerBase {

  /**
   * Input / Process a log.
   */
  public function process() {

    $output = [];
    $output[] = ["rasult" => "OK"];

    // Clean REQUEST.
    foreach ($_POST as $key => $value) {
      if (strstr($key, 'amp;')) {

        $_POST[str_replace('amp;', '', $key)] = $value;
      }
    }
    $data = [];
    $data['REQUEST_URI'] = (!empty($_POST['URL'])) ? $_POST['URL'] : "";
    if (empty($data['REQUEST_URI'])) {
      $data['REQUEST_URI'] = !empty($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : "";
    }
    $data['CAMP'] = (!empty($_POST['CAMP'])) ? $_POST['CAMP'] : "";
    $data['REFERER'] = (!empty($_POST['REFERER'])) ? $_POST['REFERER'] : "";
    $data['MOBILE'] = (!empty($_POST['MOBILE'])) ? $_POST['MOBILE'] : "";
    $data['SCREEN'] = (!empty($_POST['SCREEN'])) ? $_POST['SCREEN'] : "";
    $data['LANGUAGE'] = (!empty($_POST['LANGUAGE'])) ? $_POST['LANGUAGE'] : "";
    $data['HTTP_USER_AGENT'] = $_SERVER['HTTP_USER_AGENT'] ? $_SERVER['HTTP_USER_AGENT'] : "";
    $data['REMOTE_ADDR'] = simple_analytics_get_client_ip();
    $data['BOT'] = SimpleAnalyticsService::botDetecte();
    $data['HTTP_HOST'] = $_SERVER['HTTP_HOST'];
    $data['SERVEUR'] = json_encode($_SERVER);

    // Add to stat.
    SimpleAnalyticsActions::setStat($data);

    return new JsonResponse($output);
  }

}
